from fundb.sqlalchemy.table import BaseTable
from fundrive.core import BaseDrive
from funsecret import read_secret
from funutil import getLogger
from sqlalchemy import create_engine
from sqlalchemy.orm import Session

from funsketch.db import Sketch

from .drive import get_default_drive

logger = getLogger("funsketch")


def sync_sketch_data(
    driver: BaseDrive = None,
    sketch_fid="677b89d3768b8114e33642a0b18a3ea409f573b7",
    funsketch_fid="677b89d6711f33bdcb074e28b7bb0340fa242031",
):
    driver = driver or get_default_drive()[0]

    url = read_secret("funsketch", "db", "url")
    engine = create_engine(url, echo=False)
    BaseTable.metadata.create_all(engine)
    with Session(engine) as session:
        for file in driver.get_dir_list(sketch_fid):
            fid = driver.mkdir(fid=funsketch_fid, name=file.name)
            sketch = Sketch(fid=fid, name=file.name, video_fid=file.fid)
            sketch.upsert(session)
            session.commit()



import json

from funai.llm import get_model
from fundb.sqlalchemy.table import BaseTable
from funsecret import read_secret
from funsketch.db import Episode, Sketch
from funutil import getLogger
from sqlalchemy import create_engine
from sqlalchemy.orm import Session

from funsketch.op.drive import get_default_drive

logger = getLogger("funsketch")


def sync_episode_data():
    drive, _ = get_default_drive()
    model = get_model("deepseek")
    engine = create_engine(read_secret("funsketch", "db", "url"), echo=False)
    BaseTable.metadata.create_all(engine)
    with Session(engine) as session:
        res = BaseTable.select_all(session=session, table=Sketch)
        for sketch in res:
            data = [
                f'{data["fid"]}, name={data["name"]}'
                for data in drive.get_file_list(sketch.video_fid)
                if data["name"].endswith(".mp4")
            ]
            data = "\n".join([i for i in data])
            prompt = f"""
                下面是一部电视剧的所有文件路径，请分析这些文件名，返回视频顺序，要求返回结果是json的列表，包含path，index, name,只返回json，不要用```包含
                {data}
                """
            res = model.chat(prompt)
            res = json.loads(res)
            for data in res:
                episode = Episode(
                    fid=data["path"],
                    name=data["name"],
                    index=data["index"],
                    sketch_id=sketch.uid,
                )
                print(episode.to_dict())
                episode.upsert(session=session)
            session.commit()
